@@ -1,8 +1,8 @@
-from pypiplot.pypiplot import pypiplot
+from pypiplot.pypiplot import Pypiplot
 
 __author__ = 'Erdogan Tasksen'
 __email__ = 'erdogant@gmail.com'
-__version__ = '1.0.0'
+__version__ = '2.0.0'
 
 # module level doc-string
 __doc__ = """
@@ -15,10 +15,11 @@ Python package to count and plot the number of downloads from Pypi.
 
 Example
 -------
->>> from pypiplot import pypiplot
->>> pp = pypiplot(username='github_name')
+>>> from pypiplot import Pypiplot
+>>> pp = Pypiplot(username='erdogant')
 >>> pp.update()
 >>> pp.stats()
+>>> pp.plot_cal()
 >>> pp.plot_year()
 >>> pp.plot()
 >>>
